<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1">
<context>
    <name>CmdStartPage</name>
    <message>
        <location filename="../../Command.cpp" line="39"/>
        <source>Start</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../Command.cpp" line="40"/>
        <source>Start Page</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../Command.cpp" line="41"/>
        <source>Displays the start page in a browser view</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DlgStartPreferences</name>
    <message>
        <location filename="../../DlgStartPreferences.ui" line="14"/>
        <source>Start page options</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../DlgStartPreferences.ui" line="20"/>
        <source>Start page template</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../DlgStartPreferences.ui" line="26"/>
        <source>An optional HTML template that will be used instead of the default start page.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../DlgStartPreferences.ui" line="42"/>
        <source>Contents</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../DlgStartPreferences.ui" line="89"/>
        <source>Show notepad</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../DlgStartPreferences.ui" line="70"/>
        <source>Shows a notepad next to the file thumbnails, where you can keep notes across sessions</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../DlgStartPreferences.ui" line="146"/>
        <source>Show examples folder contents</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../DlgStartPreferences.ui" line="153"/>
        <source>If you want the examples to show on the first page</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../DlgStartPreferences.ui" line="175"/>
        <source>Show additional folder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../DlgStartPreferences.ui" line="96"/>
        <source>An optional custom folder to be displayed at the bottom of the first page.
By using &quot;;;&quot; to separate paths, you can add several folders here</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../DlgStartPreferences.ui" line="120"/>
        <source>Show forum</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../DlgStartPreferences.ui" line="127"/>
        <source>If this is checked, the latest posts from the FreeCAD forum will be displayed on the Activity tab</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../DlgStartPreferences.ui" line="113"/>
        <source>Show tips</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../DlgStartPreferences.ui" line="48"/>
        <source>Displays help tips in the Start workbench Documents tab</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../DlgStartPreferences.ui" line="182"/>
        <source>Show scrollbars</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../DlgStartPreferences.ui" line="211"/>
        <source>Fonts and colors</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../DlgStartPreferences.ui" line="217"/>
        <source>Use FreeCAD style sheet</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../DlgStartPreferences.ui" line="224"/>
        <source>If this is checked and a style sheet is specified in General preferences, it will be used and override the colors below</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../DlgStartPreferences.ui" line="243"/>
        <source>Background color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../DlgStartPreferences.ui" line="256"/>
        <source>The background color behind the panels</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../DlgStartPreferences.ui" line="279"/>
        <source>Background color down gradient</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../DlgStartPreferences.ui" line="295"/>
        <source>The down gradient for the background color (currently unsupported)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../DlgStartPreferences.ui" line="315"/>
        <source>Background image</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../DlgStartPreferences.ui" line="322"/>
        <source>An optional image to display as background</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../DlgStartPreferences.ui" line="335"/>
        <source>Background text color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../DlgStartPreferences.ui" line="348"/>
        <source>The color of the version text</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../DlgStartPreferences.ui" line="368"/>
        <source>Page background color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../DlgStartPreferences.ui" line="381"/>
        <source>The background of the main start page area</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../DlgStartPreferences.ui" line="401"/>
        <source>Page text color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../DlgStartPreferences.ui" line="414"/>
        <source>The color of the text on the main pages</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../DlgStartPreferences.ui" line="434"/>
        <source>Box background color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../DlgStartPreferences.ui" line="447"/>
        <source>The background color of the boxes inside the pages</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../DlgStartPreferences.ui" line="467"/>
        <source>Link color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../DlgStartPreferences.ui" line="480"/>
        <source>The color of the links</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../DlgStartPreferences.ui" line="500"/>
        <source>Font family</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../DlgStartPreferences.ui" line="509"/>
        <source>The font family to use on the start page. Can be a font name or a comma-separated series of fallback fonts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../DlgStartPreferences.ui" line="515"/>
        <source>Arial,Helvetica,sans</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../DlgStartPreferences.ui" line="528"/>
        <source>The base font size to use for all texts of the Start page</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../DlgStartPreferences.ui" line="531"/>
        <source>px</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../DlgStartPreferences.ui" line="552"/>
        <source>Open links</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../DlgStartPreferences.ui" line="564"/>
        <source>in FreeCAD</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../DlgStartPreferences.ui" line="583"/>
        <source>In external browser</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../DlgStartPreferences.ui" line="598"/>
        <source>Use gradient for New File icon</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../DlgStartPreferences.ui" line="605"/>
        <source>If this is selected, the &apos;New File&apos; icon shows a gradient icon instead of the normal icon</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../DlgStartPreferences.ui" line="627"/>
        <source>Options</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../DlgStartPreferences.ui" line="633"/>
        <source>Switch workbench after loading</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../DlgStartPreferences.ui" line="640"/>
        <source>Choose which workbench to switch to after the program launches</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../DlgStartPreferences.ui" line="647"/>
        <source>Close start page after loading</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../DlgStartPreferences.ui" line="654"/>
        <source>If checked, will automatically close the Start page when FreeCAD launches</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../DlgStartPreferences.ui" line="673"/>
        <source>Close and switch on opening file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../DlgStartPreferences.ui" line="680"/>
        <source>If application is started by opening a file, apply the two settings above</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Workbench</name>
    <message>
        <location filename="../../../StartPage/StartPage.py" line="640"/>
        <location filename="../../Workbench.cpp" line="66"/>
        <source>Start page</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>StartPage</name>
    <message>
        <location filename="../../../StartPage/TranslationTexts.py" line="38"/>
        <source>Start</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../StartPage/TranslationTexts.py" line="39"/>
        <source>Documents</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../StartPage/TranslationTexts.py" line="40"/>
        <source>Help</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../StartPage/TranslationTexts.py" line="41"/>
        <source>Activity</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../StartPage/TranslationTexts.py" line="42"/>
        <source>Recent files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../StartPage/TranslationTexts.py" line="43"/>
        <source>Tip</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../StartPage/TranslationTexts.py" line="44"/>
        <source>Adjust the number of recent files to be shown here in menu Edit -&gt; Preferences -&gt; General -&gt; Size of recent file list</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../StartPage/TranslationTexts.py" line="45"/>
        <source>Examples</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../StartPage/TranslationTexts.py" line="46"/>
        <source>General documentation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../StartPage/TranslationTexts.py" line="47"/>
        <source>User hub</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../StartPage/TranslationTexts.py" line="48"/>
        <source>This section contains documentation useful for FreeCAD users in general: a list of all the workbenches, detailed instructions on how to install and use the FreeCAD application, tutorials, and all you need to get started.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../StartPage/TranslationTexts.py" line="49"/>
        <source>Power users hub</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../StartPage/TranslationTexts.py" line="50"/>
        <source>This section gathers documentation for advanced users and people interested in writing python scripts. You will also find there a repository of macros, instructions on how to install and use them, and more information about customizing FreeCAD to your specific needs.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../StartPage/TranslationTexts.py" line="51"/>
        <source>Developers hub</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../StartPage/TranslationTexts.py" line="52"/>
        <source>This section contains material for developers: How to compile FreeCAD yourself, how the FreeCAD source code is structured + how to navigate in it, how to develop new workbenches and/or embed FreeCAD in your own application.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../StartPage/TranslationTexts.py" line="53"/>
        <source>Manual</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../StartPage/TranslationTexts.py" line="54"/>
        <source>The FreeCAD manual is another, more linear way to present the information contained in this wiki. It is made to be read like a book, and will gently introduce you to many other pages from the hubs above. &lt;a href=&quot;https://www.gitbook.com/book/yorikvanhavre/a-freecad-manual/details&quot;&gt;e-book versions&lt;/a&gt; are also available.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../StartPage/TranslationTexts.py" line="55"/>
        <source>Workbenches documentation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../StartPage/TranslationTexts.py" line="56"/>
        <source>These are the help pages of all the workbenches currently installed on this computer.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../StartPage/TranslationTexts.py" line="57"/>
        <source>Getting help from the community</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../StartPage/TranslationTexts.py" line="58"/>
        <source>The &lt;a href=&quot;http://forum.freecad.org&quot;&gt;FreeCAD forum&lt;/a&gt; is a great place to get help from other FreeCAD users and developers. The forum has many sections for different types of issues and discussion subjects. If in doubt, post in the more general &lt;a href=&quot;https://forum.freecad.org/viewforum.php?f=3&quot;&gt;Help on using FreeCAD&lt;/a&gt; section.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../StartPage/TranslationTexts.py" line="59"/>
        <source>If it is the first time you are posting on the forum, be sure to &lt;a href=&quot;https://forum.freecad.org/viewtopic.php?f=3&amp;t=2264&quot;&gt;read the guidelines&lt;/a&gt; first!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../StartPage/TranslationTexts.py" line="60"/>
        <source>FreeCAD also maintains a public &lt;a href=&quot;https://www.freecad.org/tracker&quot;&gt;bug tracker&lt;/a&gt; where anybody can submit bugs and propose new features. To avoid causing extra work and give the best chances to see your bug solved, make sure you read the &lt;a href=&quot;https://forum.freecad.org/viewtopic.php?f=3&amp;t=5236&quot;&gt;bug submission guide&lt;/a&gt; before posting.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../StartPage/TranslationTexts.py" line="66"/>
        <source>Below are the latest changes added to the &lt;a href=&quot;http://github.com/FreeCAD/FreeCAD/&quot;&gt;FreeCAD source code&lt;/a&gt;. These changes might not reflect yet in the FreeCAD version that you are currently running. Check the &lt;a href=&quot;https://www.freecad.org/wiki/Downloads&quot;&gt;available options&lt;/a&gt; if you wish to obtain a development version.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../StartPage/TranslationTexts.py" line="74"/>
        <source>The latest posts on the &lt;a href=&quot;https://forum.freecad.org&quot;&gt;FreeCAD forum&lt;/a&gt;:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../StartPage/TranslationTexts.py" line="61"/>
        <source>Available addons</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../StartPage/TranslationTexts.py" line="62"/>
        <source>Below is a list of available extra workbenches that can be added to your FreeCAD installation. Browse and install them from menu Tools -&gt; Addons manager. You can learn more about any of them by clicking the links below.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../StartPage/TranslationTexts.py" line="63"/>
        <source>If not bundled with your FreeCAD version, install the FreeCAD documentation package to get documentation hubs, workbench help and individual command documentation without an internet connection.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../StartPage/TranslationTexts.py" line="64"/>
        <source>Cannot fetch information from GitHub. &lt;a href=&quot;EnableDownload.py&quot;&gt;Authorize FreeCAD to access the internet&lt;/a&gt; and reload the Start page.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../StartPage/TranslationTexts.py" line="65"/>
        <source>Recent commits</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../StartPage/TranslationTexts.py" line="67"/>
        <source>See all commits on github</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../StartPage/TranslationTexts.py" line="68"/>
        <source>You can configure a custom folder to display here in menu Edit -&gt; Preferences -&gt; Start -&gt; Show additional folder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../StartPage/TranslationTexts.py" line="69"/>
        <source>version</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../StartPage/TranslationTexts.py" line="70"/>
        <source>build</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../StartPage/TranslationTexts.py" line="71"/>
        <source>Create new...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../StartPage/TranslationTexts.py" line="72"/>
        <source>Unknown</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../StartPage/TranslationTexts.py" line="73"/>
        <source>Forum</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../StartPage/TranslationTexts.py" line="75"/>
        <source>To open any of the links above in your desktop browser, Right-click -&gt; Open in external browser</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../StartPage/TranslationTexts.py" line="76"/>
        <source>Creation date</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../StartPage/TranslationTexts.py" line="77"/>
        <source>Last modification</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../StartPage/TranslationTexts.py" line="78"/>
        <source>Notes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../StartPage/TranslationTexts.py" line="79"/>
        <source>Open start page preferences</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../../AppStartGui.cpp" line="103"/>
        <source>Start</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
